California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 42 - TRANSPORTATION FUNDING: SALES AND USE TAX REVENUES. ACA 4. (2001) View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1238613 | YES ON 42 - TAXPAYERS, CONSTRUCTION, BUSINESS, LABOR, ENGINEERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1243211 | NO ON 42, A COALITION FOR TEACHERS AND SERVICE EMPLOYEES WHO OPPOSE DIVERTING FUNDS FROM SCHOOLS, HOSPITALS AND SENIORS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970230 | ASSOCIATED GENERAL CONTRACTORS ISSUES POLITICAL ACTION COMMITTEE | SUPPORT